Module runtime

Module runtime 

A Rust interface for the functionality of the Objective-C runtime.

For more information on foreign functions, see Apple’s documentation: https://developer.apple.com/library/mac/documentation/Cocoa/Reference/ObjCRuntimeRef/index.html

Structs

Class
A type that represents an Objective-C class.
Ivar
A type that represents an instance variable.
Method
A type that represents a method in a class definition.
Object
A type that represents an instance of a class.
Protocol
A type that represents an Objective-C protocol.
Sel
A type that represents a method selector.

Constants

NO
The equivalent of false for Objective-C’s BOOL type.
YES
The equivalent of true for Objective-C’s BOOL type.

Functions

class_addIvar⚠
class_addMethod⚠
class_addProtocol⚠
class_conformsToProtocol⚠
class_copyIvarList⚠
class_copyMethodList⚠
class_copyProtocolList⚠
class_createInstance⚠
class_getInstanceMethod⚠
class_getInstanceSize⚠
class_getInstanceVariable⚠
class_getName⚠
class_getSuperclass⚠
ivar_getName⚠
ivar_getOffset⚠
ivar_getTypeEncoding⚠
method_copyArgumentType⚠
method_copyReturnType⚠
method_exchangeImplementations⚠
method_getImplementation⚠
method_getName⚠
method_getNumberOfArguments⚠
method_setImplementation⚠
objc_allocateClassPair⚠
objc_allocateProtocol⚠
objc_autorelease⚠
objc_autoreleasePoolPop⚠
objc_autoreleasePoolPush⚠
objc_copyClassList⚠
objc_copyProtocolList⚠
objc_copyWeak⚠
objc_destroyWeak⚠
objc_disposeClassPair⚠
objc_getClass⚠
objc_getClassList⚠
objc_getProtocol⚠
objc_initWeak⚠
objc_loadWeakRetained⚠
objc_registerClassPair⚠
objc_registerProtocol⚠
objc_release⚠
objc_retain⚠
object_dispose⚠
object_getClass⚠
protocol_addMethodDescription⚠
protocol_addProtocol⚠
protocol_conformsToProtocol⚠
protocol_copyProtocolList⚠
protocol_getName⚠
protocol_isEqual⚠
sel_getName⚠
sel_registerName⚠

Type Aliases

BOOL
The Objective-C BOOL type.
Imp
A pointer to the start of a method implementation.